submodule (parent) parent

contains

module procedure pi2tau
  pi2tau = 2*pi
end procedure pi2tau

end submodule parent

